@@ -73,6 +73,10 @@ class Definition:
 			ExceptionApi.create_internal_error(
 					'<unset>', 'Definition name cannot be None (description={0})'.format(self.description)
 				)
+		# Nullable
+		##########
+		if self.default_value is None:
+			self.nullable = True
 		# Data Format
 		#############
 		if self.data_type is DataType.OneOf:
